@@ -1,6 +1,7 @@
 package operator
 
 import (
+	"context"
 	"crypto/x509"
 	"encoding/base64"
 	"encoding/json"
@@ -63,6 +64,9 @@ func (optr *Operator) syncAll(syncFuncs []syncFunc) error {
 		if syncErr.err != nil {
 			break
 		}
+		if err := optr.clearDegradedStatus(sf.name); err != nil {
+			return fmt.Errorf("error clearing degraded status: %v", err)
+		}
 	}
 
 	if err := optr.syncDegradedStatus(syncErr); err != nil {
@@ -93,6 +97,52 @@ func (optr *Operator) syncAll(syncFuncs []syncFunc) error {
 	return syncErr.err
 }
 
+// Return true if cloud config is required on a platform.
+func isCloudConfigRequired(infra *configv1.Infrastructure) bool {
+	if infra.Spec.CloudConfig.Name != "" {
+		return true
+	}
+	switch infra.Status.PlatformStatus.Type {
+	case configv1.AzurePlatformType,
+		configv1.GCPPlatformType,
+		configv1.OpenStackPlatformType,
+		configv1.VSpherePlatformType:
+		return true
+	default:
+		return false
+	}
+}
+
+// Sync cloud config on supported platform from cloud.conf available in openshift-config-managed/kube-cloud-config ConfigMap.
+func (optr *Operator) syncCloudConfig(spec *mcfgv1.ControllerConfigSpec, infra *configv1.Infrastructure) error {
+	if _, err := optr.clusterCmLister.ConfigMaps("openshift-config-managed").Get("kube-cloud-config"); err != nil {
+		if apierrors.IsNotFound(err) {
+			if isCloudConfigRequired(infra) {
+				// Return error only if cloud config is required, otherwise prceeds further.
+				return fmt.Errorf("%s/%s configmap is required on platform %s but not found: %v",
+					"openshift-config-managed", "kube-cloud-config", infra.Status.PlatformStatus.Type, err)
+			}
+		} else {
+			return err
+		}
+
+	} else {
+		// Read cloud.conf from openshift-config-managed/kube-cloud-config ConfigMap.
+		cc, err := optr.getCloudConfigFromConfigMap("openshift-config-managed", "kube-cloud-config", "cloud.conf")
+		if err != nil {
+			return err
+		}
+
+		spec.CloudProviderConfig = cc
+
+		caCert, err := optr.getCAsFromConfigMap("openshift-config-managed", "kube-cloud-config", "ca-bundle.pem")
+		if err == nil {
+			spec.CloudProviderCAData = caCert
+		}
+	}
+	return nil
+}
+
 func (optr *Operator) syncRenderConfig(_ *renderConfig) error {
 	if err := optr.syncCustomResourceDefinitions(); err != nil {
 		return err
@@ -101,7 +151,7 @@ func (optr *Operator) syncRenderConfig(_ *renderConfig) error {
 	if optr.inClusterBringup {
 		glog.V(4).Info("Starting inClusterBringup informers cache sync")
 		// sync now our own informers after having installed the CRDs
-		if !cache.WaitForCacheSync(optr.stopCh, optr.mcpListerSynced, optr.mcListerSynced, optr.ccListerSynced) {
+		if !cache.WaitForCacheSync(optr.stopCh, optr.ccListerSynced) {
 			return errors.New("failed to sync caches for informers")
 		}
 		glog.V(4).Info("Finished inClusterBringup informers cache sync")
@@ -202,18 +252,8 @@ func (optr *Operator) syncRenderConfig(_ *renderConfig) error {
 	}
 	spec.AdditionalTrustBundle = trustBundle
 
-	// if the cloudConfig is set in infra read the cloud config reference
-	if infra.Spec.CloudConfig.Name != "" {
-		cc, err := optr.getCloudConfigFromConfigMap("openshift-config", infra.Spec.CloudConfig.Name, infra.Spec.CloudConfig.Key)
-		if err != nil {
-			return err
-		}
-		spec.CloudProviderConfig = cc
-
-		caCert, err := optr.getCAsFromConfigMap("openshift-config", infra.Spec.CloudConfig.Name, "ca-bundle.pem")
-		if err == nil {
-			spec.CloudProviderCAData = caCert
-		}
+	if err := optr.syncCloudConfig(spec, infra); err != nil {
+		return err
 	}
 
 	//TODO: alaypatel07 remove after cluster-etcd-operator deployed via CVO as Managed
@@ -248,11 +288,7 @@ func (optr *Operator) syncRenderConfig(_ *renderConfig) error {
 
 func (optr *Operator) syncCustomResourceDefinitions() error {
 	crds := []string{
-		"manifests/machineconfig.crd.yaml",
 		"manifests/controllerconfig.crd.yaml",
-		"manifests/machineconfigpool.crd.yaml",
-		"manifests/kubeletconfig.crd.yaml",
-		"manifests/containerruntimeconfig.crd.yaml",
 	}
 
 	for _, crd := range crds {
@@ -406,7 +442,7 @@ func (optr *Operator) syncMachineConfigDaemon(config *renderConfig) error {
 	}
 
 	// Only generate a new proxy cookie secret if the secret does not exist or if it has been deleted.
-	_, err = optr.kubeClient.CoreV1().Secrets(config.TargetNamespace).Get("cookie-secret", metav1.GetOptions{})
+	_, err = optr.kubeClient.CoreV1().Secrets(config.TargetNamespace).Get(context.TODO(), "cookie-secret", metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		cookieSecretBytes, err := renderAsset(config, "manifests/machineconfigdaemon/cookie-secret.yaml")
 		if err != nil {
@@ -537,7 +573,7 @@ func (optr *Operator) syncRequiredMachineConfigPools(_ *renderConfig) error {
 				return false, nil
 			}
 			optr.setOperatorStatusExtension(&co.Status, lastErr)
-			_, err = optr.configClient.ConfigV1().ClusterOperators().UpdateStatus(co)
+			_, err = optr.configClient.ConfigV1().ClusterOperators().UpdateStatus(context.TODO(), co, metav1.UpdateOptions{})
 			if err != nil {
 				lastErr = errors.Wrapf(lastErr, "failed to update clusteroperator: %v", err)
 				return false, nil
